summaryrefslogtreecommitdiff
path: root/android/telephony/data/DataServiceCallback.java
diff options
context:
space:
mode:
authorJustin Klaassen <justinklaassen@google.com>2018-04-03 23:21:57 -0400
committerJustin Klaassen <justinklaassen@google.com>2018-04-03 23:21:57 -0400
commit4d01eeaffaa720e4458a118baa137a11614f00f7 (patch)
tree66751893566986236788e3c796a7cc5e90d05f52 /android/telephony/data/DataServiceCallback.java
parenta192cc2a132cb0ee8588e2df755563ec7008c179 (diff)
downloadandroid-28-4d01eeaffaa720e4458a118baa137a11614f00f7.tar.gz
Import Android SDK Platform P [4697573]
/google/data/ro/projects/android/fetch_artifact \ --bid 4697573 \ --target sdk_phone_armv7-win_sdk \ sdk-repo-linux-sources-4697573.zip AndroidVersion.ApiLevel has been modified to appear as 28 Change-Id: If80578c3c657366cc9cf75f8db13d46e2dd4e077
Diffstat (limited to 'android/telephony/data/DataServiceCallback.java')
-rw-r--r--android/telephony/data/DataServiceCallback.java42
1 files changed, 22 insertions, 20 deletions
diff --git a/android/telephony/data/DataServiceCallback.java b/android/telephony/data/DataServiceCallback.java
index b6a81f94..4af31b5e 100644
--- a/android/telephony/data/DataServiceCallback.java
+++ b/android/telephony/data/DataServiceCallback.java
@@ -18,6 +18,7 @@ package android.telephony.data;
import android.annotation.IntDef;
import android.annotation.SystemApi;
+import android.net.LinkProperties;
import android.os.RemoteException;
import android.telephony.Rlog;
import android.telephony.data.DataService.DataServiceProvider;
@@ -37,7 +38,7 @@ import java.util.List;
@SystemApi
public class DataServiceCallback {
- private static final String mTag = DataServiceCallback.class.getSimpleName();
+ private static final String TAG = DataServiceCallback.class.getSimpleName();
/**
* Result of data requests
@@ -46,7 +47,7 @@ public class DataServiceCallback {
@Retention(RetentionPolicy.SOURCE)
@IntDef({RESULT_SUCCESS, RESULT_ERROR_UNSUPPORTED, RESULT_ERROR_INVALID_ARG, RESULT_ERROR_BUSY,
RESULT_ERROR_ILLEGAL_STATE})
- public @interface Result {}
+ public @interface ResultCode {}
/** Request is completed successfully */
public static final int RESULT_SUCCESS = 0;
@@ -68,35 +69,35 @@ public class DataServiceCallback {
/**
* Called to indicate result for the request {@link DataServiceProvider#setupDataCall(int,
* DataProfile, boolean, boolean, boolean, DataServiceCallback)}.
*
* @param result The result code. Must be one of the {@link Result}.
* @param response Setup data call response.
*/
- public void onSetupDataCallComplete(@Result int result, DataCallResponse response) {
+ public void onSetupDataCallComplete(@ResultCode int result, DataCallResponse response) {
IDataServiceCallback callback = mCallback.get();
if (callback != null) {
try {
callback.onSetupDataCallComplete(result, response);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onSetupDataCallComplete on the remote");
+ Rlog.e(TAG, "Failed to onSetupDataCallComplete on the remote");
}
}
}
/**
* Called to indicate result for the request {@link DataServiceProvider#deactivateDataCall(int,
- * boolean, boolean, DataServiceCallback)}.
+ * int, DataServiceCallback)}
*
* @param result The result code. Must be one of the {@link Result}.
*/
- public void onDeactivateDataCallComplete(@Result int result) {
+ public void onDeactivateDataCallComplete(@ResultCode int result) {
IDataServiceCallback callback = mCallback.get();
if (callback != null) {
try {
callback.onDeactivateDataCallComplete(result);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onDeactivateDataCallComplete on the remote");
+ Rlog.e(TAG, "Failed to onDeactivateDataCallComplete on the remote");
}
}
}
@@ -105,15 +106,15 @@ public class DataServiceCallback {
* Called to indicate result for the request {@link DataServiceProvider#setInitialAttachApn(
* DataProfile, boolean, DataServiceCallback)}.
*
* @param result The result code. Must be one of the {@link Result}.
*/
- public void onSetInitialAttachApnComplete(@Result int result) {
+ public void onSetInitialAttachApnComplete(@ResultCode int result) {
IDataServiceCallback callback = mCallback.get();
if (callback != null) {
try {
callback.onSetInitialAttachApnComplete(result);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onSetInitialAttachApnComplete on the remote");
+ Rlog.e(TAG, "Failed to onSetInitialAttachApnComplete on the remote");
}
}
}
@@ -122,16 +123,16 @@ public class DataServiceCallback {
* Called to indicate result for the request {@link DataServiceProvider#setDataProfile(List,
* boolean, DataServiceCallback)}.
*
* @param result The result code. Must be one of the {@link Result}.
*/
@SystemApi
- public void onSetDataProfileComplete(@Result int result) {
+ public void onSetDataProfileComplete(@ResultCode int result) {
IDataServiceCallback callback = mCallback.get();
if (callback != null) {
try {
callback.onSetDataProfileComplete(result);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onSetDataProfileComplete on the remote");
+ Rlog.e(TAG, "Failed to onSetDataProfileComplete on the remote");
}
}
}
@@ -140,16 +141,17 @@ public class DataServiceCallback {
* Called to indicate result for the request {@link DataServiceProvider#getDataCallList(
* DataServiceCallback)}.
*
* @param result The result code. Must be one of the {@link Result}.
* @param dataCallList List of the current active data connection.
*/
- public void onGetDataCallListComplete(@Result int result, List<DataCallResponse> dataCallList) {
+ public void onGetDataCallListComplete(@ResultCode int result,
+ List<DataCallResponse> dataCallList) {
IDataServiceCallback callback = mCallback.get();
if (callback != null) {
try {
callback.onGetDataCallListComplete(result, dataCallList);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onGetDataCallListComplete on the remote");
+ Rlog.e(TAG, "Failed to onGetDataCallListComplete on the remote");
}
}
}
@@ -165,7 +167,7 @@ public class DataServiceCallback {
try {
callback.onDataCallListChanged(dataCallList);
} catch (RemoteException e) {
- Rlog.e(mTag, "Failed to onDataCallListChanged on the remote");
+ Rlog.e(TAG, "Failed to onDataCallListChanged on the remote");
}
}
}
@@ -68,35 +69,35 @@ public class DataServiceCallback {
/**
* Called to indicate result for the request {@link DataServiceProvider#setupDataCall(int,
- * DataProfile, boolean, boolean, boolean, DataServiceCallback)}.
+ * DataProfile, boolean, boolean, int, LinkProperties, DataServiceCallback)} .
*
@@ -68,35 +69,35 @@ public class DataServiceCallback {
*
- * @param result The result code. Must be one of the {@link Result}.
+ * @param result The result code. Must be one of the {@link ResultCode}.
* @param response Setup data call response.
*/
@@ -68,35 +69,35 @@ public class DataServiceCallback {
*
- * @param result The result code. Must be one of the {@link Result}.
+ * @param result The result code. Must be one of the {@link ResultCode}.
*/
@@ -105,15 +106,15 @@ public class DataServiceCallback {
* DataProfile, boolean, DataServiceCallback)}.
*
- * @param result The result code. Must be one of the {@link Result}.
+ * @param result The result code. Must be one of the {@link ResultCode}.
*/
@@ -122,16 +123,16 @@ public class DataServiceCallback {
* boolean, DataServiceCallback)}.
*
- * @param result The result code. Must be one of the {@link Result}.
+ * @param result The result code. Must be one of the {@link ResultCode}.
*/
@@ -140,16 +141,17 @@ public class DataServiceCallback {
* DataServiceCallback)}.
*
- * @param result The result code. Must be one of the {@link Result}.
+ * @param result The result code. Must be one of the {@link ResultCode}.
* @param dataCallList List of the current active data connection.
*/